@@ -1,5 +1,4 @@
-{-# LANGUAGE ConstraintKinds #-}
-{-# LANGUAGE CPP       #-}
+{-# LANGUAGE ConstraintKinds     #-}
 {-# LANGUAGE DeriveFunctor       #-}
 {-# LANGUAGE FlexibleContexts    #-}
 {-# LANGUAGE ScopedTypeVariables #-}
@@ -47,30 +46,27 @@ module Diagrams.TwoD.Polygons(
 
     ) where
 
-import           Control.Lens            (Lens', generateSignatures, lensRules,
-                                          makeLensesWith, view, (.~), (^.))
-import           Control.Monad           (forM, liftM)
-import           Control.Monad.ST        (ST, runST)
-import           Data.Array.ST           (STUArray, newArray, readArray,
-                                          writeArray)
+import           Control.Lens         (Lens', generateSignatures, lensRules,
+                                       makeLensesWith, view, (.~), (^.))
+import           Control.Monad        (forM, liftM)
+import           Control.Monad.ST     (ST, runST)
+import           Data.Array.ST        (STUArray, newArray, readArray,
+                                       writeArray)
 import           Data.Default.Class
-import           Data.List               (maximumBy, minimumBy)
-import           Data.Maybe              (catMaybes)
-#if __GLASGOW_HASKELL__ < 710
-import           Data.Monoid             (mconcat, mempty)
-#endif
-import           Data.Ord                (comparing)
+import           Data.List            (maximumBy, minimumBy)
+import           Data.Maybe           (catMaybes)
+import           Data.Ord             (comparing)
 
 import           Diagrams.Angle
 import           Diagrams.Core
 import           Diagrams.Located
 import           Diagrams.Path
-import           Diagrams.Points         (centroid)
+import           Diagrams.Points      (centroid)
 import           Diagrams.Trail
 import           Diagrams.TrailLike
 import           Diagrams.TwoD.Types
-import           Diagrams.TwoD.Vector    (leftTurn, unitX, unitY, unit_Y)
-import           Diagrams.Util           (tau, ( # ))
+import           Diagrams.TwoD.Vector (leftTurn, unitX, unitY, unit_Y)
+import           Diagrams.Util        (tau, ( # ))
 
 import           Linear.Affine
 import           Linear.Metric
@@ -174,10 +170,10 @@ polyTrail po = transform ori tr
             PolySides ans szs -> polySidesTrail ans szs
             PolyRegular n r   -> polyRegularTrail n r
         ori = case po^.polyOrient of
-            OrientH      -> orient unit_Y tr
-            OrientV      -> orient unitX  tr
-            OrientTo v   -> orient v      tr
-            NoOrient     -> mempty
+            OrientH    -> orient unit_Y tr
+            OrientV    -> orient unitX  tr
+            OrientTo v -> orient v      tr
+            NoOrient   -> mempty
 
 -- | Generate the polygon described by the given options.
 polygon :: (InSpace V2 n t, TrailLike t) => PolygonOpts n -> t
